==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkTriangle.java <==
// java wrapper for vtkTriangle object
//

package vtk;
import vtk.*;

public class vtkTriangle extends vtkCell
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetEdge_2(int id0);
  public vtkCell GetEdge(int id0) {
    long temp = GetEdge_2(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetCellType_3();
  public int GetCellType()
    { return GetCellType_3(); }

  private native int GetCellDimension_4();
  public int GetCellDimension()
    { return GetCellDimension_4(); }

  private native int GetNumberOfEdges_5();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_5(); }

  private native int GetNumberOfFaces_6();
  public int GetNumberOfFaces()
    { return GetNumberOfFaces_6(); }

  private native long GetFace_7(int id0);
  public vtkCell GetFace(int id0) {
    long temp = GetFace_7(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int CellBoundary_8(int id0,double id1[],vtkIdList id2);
  public int CellBoundary(int id0,double id1[],vtkIdList id2)
    { return CellBoundary_8(id0,id1,id2); }

  private native void Contour_9(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10);
  public void Contour(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10)
    { Contour_9(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10); }

  private native int Triangulate_10(int id0,vtkIdList id1,vtkPoints id2);
  public int Triangulate(int id0,vtkIdList id1,vtkPoints id2)
    { return Triangulate_10(id0,id1,id2); }

  private native double ComputeArea_11();
  public double ComputeArea()
    { return ComputeArea_11(); }

  private native void Clip_12(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9);
  public void Clip(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9)
    { Clip_12(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native void InterpolationFunctions_13(double id0[],double id1[]);
  public void InterpolationFunctions(double id0[],double id1[])
    { InterpolationFunctions_13(id0,id1); }

  private native void InterpolationDerivs_14(double id0[],double id1[]);
  public void InterpolationDerivs(double id0[],double id1[])
    { InterpolationDerivs_14(id0,id1); }

  private native void InterpolateFunctions_15(double id0[],double id1[]);
  public void InterpolateFunctions(double id0[],double id1[])
    { InterpolateFunctions_15(id0,id1); }

  private native void InterpolateDerivs_16(double id0[],double id1[]);
  public void InterpolateDerivs(double id0[],double id1[])
    { InterpolateDerivs_16(id0,id1); }

  private native int GetParametricCenter_17(double id0[]);
  public int GetParametricCenter(double id0[])
    { return GetParametricCenter_17(id0); }

  private native double GetParametricDistance_18(double id0[]);
  public double GetParametricDistance(double id0[])
    { return GetParametricDistance_18(id0); }

  private native void TriangleCenter_19(double id0[],double id1[],double id2[],double id3[]);
  public void TriangleCenter(double id0[],double id1[],double id2[],double id3[])
    { TriangleCenter_19(id0,id1,id2,id3); }

  private native double TriangleArea_20(double id0[],double id1[],double id2[]);
  public double TriangleArea(double id0[],double id1[],double id2[])
    { return TriangleArea_20(id0,id1,id2); }

  private native double Circumcircle_21(double id0[],double id1[],double id2[],double id3[]);
  public double Circumcircle(double id0[],double id1[],double id2[],double id3[])
    { return Circumcircle_21(id0,id1,id2,id3); }

  private native int BarycentricCoords_22(double id0[],double id1[],double id2[],double id3[],double id4[]);
  public int BarycentricCoords(double id0[],double id1[],double id2[],double id3[],double id4[])
    { return BarycentricCoords_22(id0,id1,id2,id3,id4); }

  private native int ProjectTo2D_23(double id0[],double id1[],double id2[],double id3[],double id4[],double id5[]);
  public int ProjectTo2D(double id0[],double id1[],double id2[],double id3[],double id4[],double id5[])
    { return ProjectTo2D_23(id0,id1,id2,id3,id4,id5); }

  private native void ComputeNormal_24(double id0[],double id1[],double id2[],double id3[]);
  public void ComputeNormal(double id0[],double id1[],double id2[],double id3[])
    { ComputeNormal_24(id0,id1,id2,id3); }

  private native void ComputeNormalDirection_25(double id0[],double id1[],double id2[],double id3[]);
  public void ComputeNormalDirection(double id0[],double id1[],double id2[],double id3[])
    { ComputeNormalDirection_25(id0,id1,id2,id3); }

  private native int PointInTriangle_26(double id0[],double id1[],double id2[],double id3[],double id4);
  public int PointInTriangle(double id0[],double id1[],double id2[],double id3[],double id4)
    { return PointInTriangle_26(id0,id1,id2,id3,id4); }

  private native void ComputeQuadric_27(double id0[],double id1[],double id2[],vtkQuadric id3);
  public void ComputeQuadric(double id0[],double id1[],double id2[],vtkQuadric id3)
    { ComputeQuadric_27(id0,id1,id2,id3); }

  public vtkTriangle() { super(); }

  public vtkTriangle(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-armv7h.pkg.tar.xz: vtk/vtkTriangle.java <==
// java wrapper for vtkTriangle object
//

package vtk;
import vtk.*;

public class vtkTriangle extends vtkCell
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetEdge_2(int id0);
  public vtkCell GetEdge(int id0) {
    long temp = GetEdge_2(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetCellType_3();
  public int GetCellType()
    { return GetCellType_3(); }

  private native int GetCellDimension_4();
  public int GetCellDimension()
    { return GetCellDimension_4(); }

  private native int GetNumberOfEdges_5();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_5(); }

  private native int GetNumberOfFaces_6();
  public int GetNumberOfFaces()
    { return GetNumberOfFaces_6(); }

  private native long GetFace_7(int id0);
  public vtkCell GetFace(int id0) {
    long temp = GetFace_7(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int CellBoundary_8(int id0,double id1[],vtkIdList id2);
  public int CellBoundary(int id0,double id1[],vtkIdList id2)
    { return CellBoundary_8(id0,id1,id2); }

  private native void Contour_9(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10);
  public void Contour(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10)
    { Contour_9(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10); }

  private native int Triangulate_10(int id0,vtkIdList id1,vtkPoints id2);
  public int Triangulate(int id0,vtkIdList id1,vtkPoints id2)
    { return Triangulate_10(id0,id1,id2); }

  private native double ComputeArea_11();
  public double ComputeArea()
    { return ComputeArea_11(); }

  private native void Clip_12(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9);
  public void Clip(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9)
    { Clip_12(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native void InterpolationFunctions_13(double id0[],double id1[]);
  public void InterpolationFunctions(double id0[],double id1[])
    { InterpolationFunctions_13(id0,id1); }

  private native void InterpolationDerivs_14(double id0[],double id1[]);
  public void InterpolationDerivs(double id0[],double id1[])
    { InterpolationDerivs_14(id0,id1); }

  private native void InterpolateFunctions_15(double id0[],double id1[]);
  public void InterpolateFunctions(double id0[],double id1[])
    { InterpolateFunctions_15(id0,id1); }

  private native void InterpolateDerivs_16(double id0[],double id1[]);
  public void InterpolateDerivs(double id0[],double id1[])
    { InterpolateDerivs_16(id0,id1); }

  private native int GetParametricCenter_17(double id0[]);
  public int GetParametricCenter(double id0[])
    { return GetParametricCenter_17(id0); }

  private native double GetParametricDistance_18(double id0[]);
  public double GetParametricDistance(double id0[])
    { return GetParametricDistance_18(id0); }

  private native void TriangleCenter_19(double id0[],double id1[],double id2[],double id3[]);
  public void TriangleCenter(double id0[],double id1[],double id2[],double id3[])
    { TriangleCenter_19(id0,id1,id2,id3); }

  private native double TriangleArea_20(double id0[],double id1[],double id2[]);
  public double TriangleArea(double id0[],double id1[],double id2[])
    { return TriangleArea_20(id0,id1,id2); }

  private native double Circumcircle_21(double id0[],double id1[],double id2[],double id3[]);
  public double Circumcircle(double id0[],double id1[],double id2[],double id3[])
    { return Circumcircle_21(id0,id1,id2,id3); }

  private native int BarycentricCoords_22(double id0[],double id1[],double id2[],double id3[],double id4[]);
  public int BarycentricCoords(double id0[],double id1[],double id2[],double id3[],double id4[])
    { return BarycentricCoords_22(id0,id1,id2,id3,id4); }

  private native int ProjectTo2D_23(double id0[],double id1[],double id2[],double id3[],double id4[],double id5[]);
  public int ProjectTo2D(double id0[],double id1[],double id2[],double id3[],double id4[],double id5[])
    { return ProjectTo2D_23(id0,id1,id2,id3,id4,id5); }

  private native void ComputeNormal_24(double id0[],double id1[],double id2[],double id3[]);
  public void ComputeNormal(double id0[],double id1[],double id2[],double id3[])
    { ComputeNormal_24(id0,id1,id2,id3); }

  private native void ComputeNormalDirection_25(double id0[],double id1[],double id2[],double id3[]);
  public void ComputeNormalDirection(double id0[],double id1[],double id2[],double id3[])
    { ComputeNormalDirection_25(id0,id1,id2,id3); }

  private native int TrianglesIntersect_26(double id0[],double id1[],double id2[],double id3[],double id4[],double id5[]);
  public int TrianglesIntersect(double id0[],double id1[],double id2[],double id3[],double id4[],double id5[])
    { return TrianglesIntersect_26(id0,id1,id2,id3,id4,id5); }

  private native int PointInTriangle_27(double id0[],double id1[],double id2[],double id3[],double id4);
  public int PointInTriangle(double id0[],double id1[],double id2[],double id3[],double id4)
    { return PointInTriangle_27(id0,id1,id2,id3,id4); }

  private native void ComputeQuadric_28(double id0[],double id1[],double id2[],vtkQuadric id3);
  public void ComputeQuadric(double id0[],double id1[],double id2[],vtkQuadric id3)
    { ComputeQuadric_28(id0,id1,id2,id3); }

  public vtkTriangle() { super(); }

  public vtkTriangle(long id) { super(id); }
  public native long   VTKInit();

}
